@@ -26,14 +26,8 @@ def backlinks_list():
         print e.code
         print e.read()
 
-    output_code = '<ul class="interesting_links">' + resp.read() + '</ul>'
-    
-    edits = [('color: #000000; font-size: 10px; font-family: verdana; ', ''),
-                ('border: 0px solid #FFFFFF; ', ''),
-                ('<a ', '<li><a '),
-                ('</a>', '</a></li>')]
-    for search, replace in edits:
-        output_code = output_code.replace(search, replace)
+    links = resp.read()
+    output_code = '%s' % links
 
     return {
         'links': output_code
@@ -41,8 +35,11 @@ def backlinks_list():
 
 """
 Template:
-{% load cache %}
 
+Now:
+{{ backlinks_list }}
+
+Before:
 {% cache 21600 backlinks %}
 {{ links|safe }}
 {% endcache %}
